var u = require('./util')

exports.help = `
Usage: git ssb create-id [--name <name> | --no-name] [<options>]

  Create a new git-ssb repo and output its URL.

Options:
  --upstream <id>     id, url, or remote name of repo to create a fork of
  --name <name>       Name to give the repo. Required unless '--no-name' is given
  --no-name           Don't name the repo
  --private           Make repo private
  --recps <feed>,...  List of recipients for a private repo. Implies --private
`

exports.fn = function (argv) {
  if (argv._.length > 0 || argv.name == null) return u.help('create-id')

  u.getSbot(argv, function (err, sbot) {
    if (err) throw err
    var upstream = argv.upstream && u.getRemote(argv.upstream)
    u.getRecps(sbot, argv, function (err, recps) {
      if (err) throw err
      require('ssb-git-repo').createRepo(sbot, {
        upstream: upstream,
        name: argv.name,
        recps: recps,
      }, function (err, repo) {
        if (err) throw err
        var url = 'ssb://' + repo.id
        console.log(url)
        repo.close()
        sbot.close()
      })
    })
  })
}
