var proc = require('child_process')
var u = require('./util')
var path = require('path')

exports.help = `
Usage: git ssb create <remote> [<name>]

  Create a new git-ssb repo and add it as a git remote

Arguments:
  remote    Name of the remote to add. e.g. 'origin' or 'ssb'
  name      Name to give the repo, if any

Options:
  --private           Make repo private
  --recps <feed>,...  List of recipients for a private repo. Implies --private
`

function hasRemote(name) {
  var child = proc.spawnSync('git', ['remote'])
  if (child.status !== 0) throw u.gitError(child.stderr)
  var remotes = child.stdout.toString().split(/\n/)
  return !!~remotes.indexOf(name)
}

exports.fn = function (argv) {
  if (argv._.length < 1 || argv._.length > 2) return u.help('create')

  module.exports.createRepo(argv, argv._[0], argv._[1]);
}

exports.createRepo = function (config, remoteName, name, upstream) {
  if (!remoteName) throw 'Missing remote name'
  if (hasRemote(remoteName)) throw `Remote '${remoteName}' already exists`

  // If no name is given, use the current directory's name.
  if (!name) name = path.basename(process.cwd())

  u.getSbot(config, function (err, sbot) {
    if (err) throw err
    u.getRecps(sbot, config, function (err, recps) {
      if (err) throw err
      require('ssb-git-repo').createRepo(sbot, {
        upstream: upstream,
        name: name,
        recps: recps,
      }, function (err, repo) {
        if (err) throw err
        var url = 'ssb://' + repo.id
        console.log('Created repo:', url, name ? '(' + name + ')' : '')
        proc.spawnSync('git', ['remote', 'add', remoteName, url])
        console.log('Added remote:', remoteName)
        repo.close()
        sbot.close()
      })
    })
  })
}

