var pull = require('pull-stream')
var u = require('./util')
var cat = require('pull-cat')

exports.help = `
Usage: git ssb named [name]

  Find repos by name

Arguments:
  name      search term to look for in names
`

exports.fn = function (argv) {
  if (argv._.length !== 1) return u.help('named')

  var searchRegexp = new RegExp(argv._[0])
  process.stderr.write('Searching...\r')

  u.getSbot(argv, function (err, sbot) {
    if (err) throw err
    pull(
      cat([
        sbot.messagesByType('git-repo'),
        sbot.links({
          rel: 'about',
          dest: '%',
          values: true,
        })
      ]),
      pull.filter(function (msg) {
        var c = msg.value.content
        return searchRegexp.test(c.name)
      }),
      pull.map(function (msg) {
        var c = msg.value.content
        var key = c.about || msg.key
        return 'ssb://' + key + ' ' + c.name
      }),
      pull.unique(),
      pull.log(function (err) {
        if (err) throw err
          process.exit(0)
      })
    )
  })
}

